@@ -111,6 +111,13 @@ def check_that_all_phenotypes_have_assoc_files(phenolist):
         if not isinstance(pheno['assoc_files'], list): raise PheWebError("Assoc_files is not a list for some phenotypes.  I don't know how that happened but it's bad.")
         if any(not isinstance(s, str) for s in pheno['assoc_files']): raise PheWebError("assoc_files contains things other than strings for some phenotypes.")
 
+def check_that_num_samples_controls_cases_agree(phenolist):
+    for pheno in phenolist:
+        if all(key in pheno for key in ['num_samples', 'num_cases', 'num_controls']):
+            total_samples = pheno['num_cases'] + pheno['num_controls']
+            if pheno['num_samples'] != total_samples:
+                raise PheWebError("The pheno {} has num_samples={} but num_cases+num_controls={}: {}".format(pheno['phenocode'], pheno['num_samples'], total_samples, pheno))
+
 def extract_info_from_assoc_files(phenolist):
     for pheno in tqdm.tqdm(phenolist, bar_format='Read {n:7} files'):
         pheno.update(PhenoReader(pheno).get_info())
@@ -142,48 +149,20 @@ def import_phenolist(filepath, has_header):
     # It'd be great to use pandas for this.
     if not os.path.exists(filepath):
         raise PheWebError("ERROR: unable to import {!r} because it doesn't exist".format(filepath))
-    # 1. try openpyxl.
-    phenos = _import_phenolist_xlsx(filepath, has_header)
-    if phenos is not None:
-        return phenos
     with read_maybe_gzip(filepath) as f:
-        # 2. try json.load(f)
+        # Try json.load(f)
         try:
             return json.load(f)
         except ValueError:
             if filepath.endswith('.json'):
                 raise PheWebError("The filepath {!r} ends with '.json' but reading it as json failed.".format(filepath))
-        # 3. try csv.reader() with csv.Sniffer().sniff()
+        # Try csv.reader() with csv.Sniffer().sniff()
         f.seek(0)
         phenos = _import_phenolist_csv(f, has_header)
         if phenos is not None:
             return phenos
         raise PheWebError("I couldn't figure out how to open the file {!r}, sorry.".format(filepath))
 
-def _import_phenolist_xlsx(filepath, has_header):
-    import openpyxl
-    try:
-        wb = openpyxl.load_workbook(filepath)
-        assert len(wb.worksheets) == 1
-        sheet = wb.worksheets[0]
-        rows = [[cell.value for cell in row] for row in sheet.rows]
-        num_cols = len(rows[0])
-        if has_header:
-            fieldnames, rows = rows[0], rows[1:]
-            if any(fieldname is None or fieldname == '' for fieldname in fieldnames):
-                if has_header == 'augment':
-                    fieldnames = [i if fieldname is None else fieldname for i, fieldname in enumerate(fieldnames)]
-                else:
-                    raise PheWebError('bad xlsx header')
-            assert len(set(fieldnames)) == len(fieldnames), fieldnames
-        else:
-            fieldnames = list(range(num_cols))
-        return [{fieldnames[i]: row[i] for i in range(num_cols)} for row in rows]
-    except openpyxl.utils.exceptions.InvalidFileException:
-        if filepath.endswith('.xlsx'):
-            raise PheWebError("The filepath {!r} ends with '.xlsx' but reading it as an excel file failed.".format(filepath))
-        return None
-
 def _import_phenolist_csv(f, has_header):
     # Note: If a csv (1) contains commas in quoted cells and (2) doesn't have any line that starts with a quoted cell,
     #       then sometimes this makes very bad choices.
@@ -329,45 +308,6 @@ def merge_in_info(phenolist, more_info_rows):
             pheno[key] = row[key]
     return phenolist
 
-# def merge_in_info(phenos, more_info_rows):
-#     # TODO: do some special-casing for category and phenostring, since we have to have exactly one of each.
-#     keys_that_cant_be_lists = {'category_string', 'phenostring'}
-#     keys_to_add = {key for row in more_info_rows for key in row} - {key for row in phenos for key in row}
-#     keys_to_add_that_are_dicts = {key for key in keys_to_add if any(isinstance(row[key], dict) for row in more_info_rows)}
-#     for key in keys_to_add_that_are_dicts:
-#         assert all(isinstance(row[key], dict) for row in more_info_rows)
-#     phenos_by_phenocode = {pheno['phenocode']: pheno for pheno in phenos}
-#     for more_info_row in more_info_rows:
-#         pheno = phenos_by_phenocode.get(more_info_row['phenocode'], None)
-#         if pheno is not None:
-#             for key in more_info_row:
-#                 if key in keys_that_cant_be_lists:
-#                     if key in pheno:
-#                         assert pheno[key] == more_info_row[key], (key, pheno, more_info_row)
-#                     else:
-#                         pheno[key] = more_info_row[key]
-#                 elif key in keys_to_add:
-#                     if key in keys_to_add_that_are_dicts:
-#                         pheno.setdefault(key, set()).add(_hashabledict(more_info_row[key]))
-#                     else:
-#                         pheno.setdefault(key, set()).add(more_info_row[key])
-#                 elif key in pheno:
-#                     assert pheno[key] == more_info_row[key]
-#                 else:
-#                     print("wat?")
-#     keys_with_multiple_items = set(key for key in keys_to_add-keys_that_cant_be_lists if any(key not in pheno or len(pheno[key]) != 1 for pheno in phenos))
-#     for pheno in phenos:
-#         for key in keys_to_add:
-#             if key in keys_with_multiple_items:
-#                 try:
-#                     pheno[key] = sorted(pheno[key])
-#                 except:
-#                     pheno[key] = list(pheno.get(key, []))
-#             elif key not in keys_that_cant_be_lists:
-#                 assert len(pheno[key]) == 1
-#                 pheno[key] = next(iter(pheno[key]))
-
-
 def unique_phenocode(phenolist, new_column_name):
     # if new_column_name is None, that means that we want to keep all the columns independent.
     # so, for example, [{LDL, a, 5}, {LDL, b, 2}] -> [{LDL, [a,b], [2,5]}]
@@ -541,6 +481,7 @@ def run(argv):
         check_that_columns_are_present(phenolist, ['phenocode', 'assoc_files'] + args.required_columns)
         check_that_phenocode_is_unique(phenolist)
         check_that_all_phenotypes_have_assoc_files(phenolist)
+        check_that_num_samples_controls_cases_agree(phenolist)
         print("The {} phenotypes in {!r} look good.".format(len(phenolist), filepath))
     p = subparsers.add_parser('verify', help='check that pheno-list is well-formed and could plausibly be used to make a pheweb')
     p.add_argument('-f', dest="filepath", help="pheno-list filepath to check (default: {!r})".format(default_phenolist_filepath))
@@ -584,7 +525,7 @@ def run(argv):
         phenolist = listify_assoc_files(phenolist)
         phenolist = numify_numeric_cols(phenolist)
         save_phenolist(phenolist, filepath)
-    p = subparsers.add_parser('import-phenolist', help='read a csv, tsv, gzipped csv, gzipped tsv, or xlsx file and produce a json file')
+    p = subparsers.add_parser('import-phenolist', help='read a csv or tsv, optionally gzipped, and produce a json file')
     p.add_argument('input_filepath', help="input filepath")
     p.add_argument('-f', dest="filepath", help="output filepath (default: {!r})".format(default_phenolist_filepath))
     p.add_argument('--no-header', dest="no_header", action="store_true", help="whether input_filepath has no header, in which case columns will just be numbered")
